var assert = require('assert')
  , validate = require('../index.js')

describe('validate()', function () {
  it('should return a function with a test method', function () {
    var fn = validate('email')
    assert.equal('function', typeof fn)
    assert.equal('function', typeof fn.test)
  })

  it('should throw an Error if "type" is not defined', function () {
    assert.throws(
      function() {
        validate('notimplemented').test('string')
      },
      Error
    )
  })
})

describe('length', function() {
  it('validating: length:15', function() {
    assert.equal(true, validate('length:15').test('qwertyuiopasdfg'))
    assert.equal(false, validate('length:15').test('qwer'))
  })

  it('validating: length:3-10', function() {
    assert.equal(false, validate('length:3-10').test('qwertyuiopasdfg'))
    assert.equal(true, validate('length:3-10').test('qwerdfg'))
    assert.equal(false, validate('length:3-10').test('qw'))
  })
})

describe('email', function() {
  it('validating: email', function() {
    assert.equal(true, validate('email').test('user@domain.com'))
    assert.equal(false, validate('email').test('qwer2312'))
  })
})

describe('creditcard', function() {
  it('validating: creditcard', function() {
    assert.equal(true, validate('creditcard').test('4256035325037975'))
    assert.equal(false, validate('creditcard').test('000000'))
    assert.equal(false, validate('creditcard').test('425603532503797-'))
  })
})

describe('numeric', function() {
  it('validating: numeric', function() {
    assert.equal(true, validate('numeric').test('1234567890'))
    assert.equal(false, validate('numeric').test('qwer2312'))
  })
})

describe('alpha', function() {
  it('validating: alpha', function() {
    assert.equal(true, validate('alpha').test('aewsrdtfyguhicjo'))
    assert.equal(false, validate('alpha').test('qwer2312'))
  })
})

describe('alphanumeric', function() {
  it('validating: alphanumeric', function() {
    assert.equal(true, validate('alphanumeric').test('aewsrdt32432'))
    assert.equal(false, validate('alphanumeric').test('3209dunsa.d,'))
  })
})

describe('integer', function() {
  it('validating: integer', function() {
    assert.equal(true, validate('integer').test('123'))
    assert.equal(false, validate('integer').test('123.00'))
  })
})

describe('decimal', function() {
  it('validating: decimal', function() {
    assert.equal(true, validate('decimal').test('123'))
    assert.equal(true, validate('decimal').test('123.23'))
    assert.equal(true, validate('decimal').test('.23'))
    assert.equal(true, validate('decimal').test('0.23'))
    assert.equal(false, validate('decimal').test('1329h'))
  })
})

describe('hexadecimal', function() {
  it('validating: hexadecimal', function() {
    assert.equal(true, validate('hexadecimal').test('FFF'))
    assert.equal(true, validate('hexadecimal').test('FFFFFF'))
    assert.equal(true, validate('hexadecimal').test('0xFFFFFF'))
    assert.equal(true, validate('hexadecimal').test('0XFFFFFF'))
    assert.equal(false, validate('hexadecimal').test('0xG'))
    assert.equal(false, validate('hexadecimal').test('1329h'))
  })
})

describe('colorhex', function() {
  it('validating: colorhex', function() {
    assert.equal(true, validate('colorhex').test('#fafe10'))
    assert.equal(true, validate('colorhex').test('#fff'))
    assert.equal(false, validate('colorhex').test('#fafe1l'))
  })
})


